spannertools.StaffLinesSpanner
==============================

.. abjad-lineage:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner

.. autoclass:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.append
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.append_left
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.components
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.detach
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.extend
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.extend_left
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.fracture
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.fuse
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.get_duration
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.get_timespan
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.index
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.leaves
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.lines
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.pop
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.pop_left
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__contains__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__copy__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__eq__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__format__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__getitem__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__len__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__lt__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__ne__
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.lines
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.__repr__
   :noindex:
